@@ -1,16 +1,15 @@
 #[macro_use] extern crate clap;
 
 use std::process::{ Command, Stdio };
-use std::path::{ PathBuf};
 
 use anyhow::{ Result };
 use env_logger::Builder;
-use log::{ info, warn, error, LevelFilter};
+use log::{ info, LevelFilter};
 use clap::{ 
     Arg, App, AppSettings
 };
 
-use printnanny_services::config::{ ApiConfig, PrintNannyConfig};
+use printnanny_services::config::{ PrintNannyConfig};
 use printnanny_services::janus::{ JanusAdminEndpoint, janus_admin_api_call };
 use printnanny_services::mqtt::{ MQTTWorker, MqttAction };
 use printnanny_cli::device::{DeviceCmd, DeviceAction };
@@ -21,10 +20,10 @@ async fn main() -> Result<()> {
     let app_name = "printnanny";
 
     let app = App::new(app_name)
-        .version(crate_version!())
         .setting(AppSettings::SubcommandRequiredElseHelp)
         .author(crate_authors!())
         .about(crate_description!())
+        .version(crate_version!())
         .arg(Arg::new("v")
         .short('v')
         .multiple_occurrences(true)
@@ -33,10 +32,12 @@ async fn main() -> Result<()> {
             .long("config")
             .short('c')
             .takes_value(true)
-            .required(true)
             .help("Path to Config.toml (see env/ for examples)"))
         // janusadmin
         .subcommand(App::new("janus-admin")
+            .author(crate_authors!())
+            .about(crate_description!())
+            .version(crate_version!())
             .about("Interact with Janus admin/monitoring APIs https://janus.conf.meetecho.com/docs/auth.html#token")
             .arg(Arg::new("host")
                 .long("host")
@@ -88,7 +89,10 @@ async fn main() -> Result<()> {
             ))
         // api endpoints (used by ansible facts.d)
         .subcommand(App::new("factsd")
-            .about("REST API JSON for Ansible facts.d")
+            .author(crate_authors!())
+            .about(crate_description!())
+            .version(crate_version!())
+            .about("Config serializer (JSON) intended for use with Ansible facts.d")
             .arg(Arg::new("output")
                 .short('o')
                 .long("output")
@@ -96,6 +100,9 @@ async fn main() -> Result<()> {
             ))
         // device
         .subcommand(App::new("device")
+            .author(crate_authors!())
+            .about(crate_description!())
+            .version(crate_version!())
             .about("Interact with device REST API")
             // model
             .arg(Arg::new("action")
@@ -109,6 +116,10 @@ async fn main() -> Result<()> {
             ))
         // mqtt <subscribe|publish>
         .subcommand(App::new("mqtt")
+            .author(crate_authors!())
+            .about(crate_description!())
+            .version(crate_version!())
+            .about("Interact with MQTT pub/sub service")
             .arg(Arg::new("ca_certs")
                 .long("ca-certs")
                 .takes_value(true)
@@ -130,6 +141,10 @@ async fn main() -> Result<()> {
             ))
 
         .subcommand(App::new("monitor")
+            .author(crate_authors!())
+            .about(crate_description!())
+            .version(crate_version!())
+            .about("Interact with Print Nanny monitoring service")
             .setting(AppSettings::SubcommandRequiredElseHelp)
             .subcommand(
                 App::new("start")
